# Introduction

Work in progress CNAB file writer based on [QuilhaSoft/OpenCnabPHP](https://github.com/QuilhaSoft/OpenCnabPHP).

---

All my thanks to every contributor to `OpenCnabPHP` project.

---

TODO: better this repository README.

